# {%= name %} {%= badge("fury") %}

> {%= description %}

## Install
{%= include("install") %}

## Example

```js
var isFalsey = require('{%= name %}');
console.log(isFalsey('');
//=> `true`
```

## Why?

There are other libs that do similar things, but I wanted a lib that was geared towards options handling, so that if a user defines `"null"` in YAML and it's returned as a string it will still be evaluated as `null` - and thus falsey. See the [special cases](#special-cases) for examples.

## Examples

All of the following return `true`

```js
isFalsey(undefined);
isFalsey(null);
isFalsey(false);
!isFalsey(true);
isFalsey(0);
!isFalsey(1);
isFalsey('');
!isFalsey('1');
isFalsey(NaN);
isFalsey({});
!isFalsey({a: 'b'});
isFalsey([]);
!isFalsey([0]);

(function(){
  isFalsey(arguments);
}();
(function(one){
  !isFalsey(arguments);
}(0);

(function(){
  var args = [].slice.call(arguments);
  isFalsey(args);
}();
(function(one){
  var args = [].slice.call(arguments);
  !isFalsey(args);
}(0);
```

### Special cases

There are only four "special cases", `['false', 'none', 'nil', 'null]`, and these are easily overridden by passing a value as a second parameter, e.g.

```js
isFalsey(foo, []);

// other examples...
isFalsey('false');
!isFalsey('false', []); // override special cases
!isFalsey('true');
isFalsey('nil');
!isFalsey('nil', []); // override special cases
isFalsey('none');
!isFalsey('none', []); // override special cases
isFalsey('null');
!isFalsey('null', []); // override special cases
```

Or, pass an array of values that should return `true` when evaluated as _falsey_:

```js
isFalsey(foo, ['no', 'nope', 'nada', 'zilch']);
// you get the point
```

## Author
{%= include("author") %}

## License
{%= copyright() %}
{%= license() %}

***

{%= include("footer") %}