# falsey [![NPM version](https://badge.fury.io/js/falsey.png)](http://badge.fury.io/js/falsey)

> Returns true if `value` is falsey. Strings, arrays and `arguments` objects with a length of `0`, and objects with no own enumerable properties are considered falsey.

## Install
Install with [npm](npmjs.org):

```bash
npm i falsey --save-dev
```

## Example

```js
var isFalsey = require('falsey');
console.log(isFalsey('');
//=> `true`

console.log(isFalsey(0);
//=> `true`

console.log(isFalsey(null);
//=> `true`

console.log(isFalsey('nil', ['nil', 'false']); // pass special cases
//=> `true`
```

## Why?

There are other libs that do similar things, but I wanted a lib that was geared towards options handling, so that if a user defines `"null"` in YAML and it's returned as a string it will still be evaluated as `null` - and thus falsey. See the [special cases](#special-cases) for examples.

## Examples

All of the following return `true`

```js
isFalsey(undefined);
isFalsey(null);
isFalsey(false);
!isFalsey(true);
isFalsey(0);
!isFalsey(1);
isFalsey('');
!isFalsey('1');
isFalsey(NaN);
isFalsey({});
!isFalsey({a: 'b'});
isFalsey([]);
!isFalsey([0]);

(function(){
  isFalsey(arguments);
}();
(function(one){
  !isFalsey(arguments);
}(0);

(function(){
  var args = [].slice.call(arguments);
  isFalsey(args);
}();
(function(one){
  var args = [].slice.call(arguments);
  !isFalsey(args);
}(0);
```

### Special cases

There are only four "special cases", `['false', 'none', 'nil', 'null]`, and these are easily overridden by passing a value as a second parameter, e.g.

```js
isFalsey(foo, []);

// other examples...
isFalsey('false');
!isFalsey('false', []); // override special cases
!isFalsey('true');
isFalsey('nil');
!isFalsey('nil', []); // override special cases
isFalsey('none');
!isFalsey('none', []); // override special cases
isFalsey('null');
!isFalsey('null', []); // override special cases
```

Or, pass an array of values that should return `true` when evaluated as _falsey_:

```js
isFalsey(foo, ['no', 'nope', 'nada', 'zilch']);
// you get the point
```

## Author

**Jon Schlinkert**

+ [github/jonschlinkert](https://github.com/jonschlinkert)
+ [twitter/jonschlinkert](http://twitter.com/jonschlinkert)

## License
Copyright (c) 2014 Jon Schlinkert, contributors.
Released under the MIT license

***

_This file was generated by [verb-cli](https://github.com/assemble/verb-cli) on July 08, 2014._